==> SugarCE-6.2.1.zip: SugarCE-Full-6.2.1/include/MVC/Controller/action_view_map.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*
 * Created on May 14, 2007
 *
 * To change the template for this generated file go to
 * Window - Preferences - PHPeclipse - PHP - Code Templates
 */
 //format '<action_name>' => '<view_name>'
$action_view_map['multieditview']= 'multiedit';
$action_view_map['detailview']= 'detail';
$action_view_map['editview']= 'edit';
$action_view_map['listview']= 'list';
$action_view_map['popup']= 'popup';
$action_view_map['vcard']= 'vcard';
$action_view_map['importvcard']= 'importvcard';
$action_view_map['importvcardsave']= 'importvcardsave';
$action_view_map['modulelistmenu']= 'modulelistmenu';

// SugarPDF
$action_view_map['sugarpdf']= 'sugarpdf';
$action_view_map['dc'] = 'dc';
$action_view_map['dcajax'] = 'dcajax';
$action_view_map['quick'] = 'quick';
$action_view_map['quickcreate'] = 'quickcreate';
$action_view_map['spot'] = 'spot';
$action_view_map['inlinefield'] = 'inlinefield';
$action_view_map['inlinefieldsave'] = 'inlinefieldsave';
$action_view_map['pluginlist'] = 'plugins';
$action_view_map['downloadplugin'] = 'downloadplugin';
?>

==> SugarCE-6.4.6.zip: SugarCE-Full-6.4.6/include/MVC/Controller/action_view_map.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2012 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*
 * Created on May 14, 2007
 *
 * To change the template for this generated file go to
 * Window - Preferences - PHPeclipse - PHP - Code Templates
 */
 //format '<action_name>' => '<view_name>'
$action_view_map['multieditview']= 'multiedit';
$action_view_map['detailview']= 'detail';
$action_view_map['editview']= 'edit';
$action_view_map['listview']= 'list';
$action_view_map['popup']= 'popup';
$action_view_map['vcard']= 'vcard';
$action_view_map['importvcard']= 'importvcard';
$action_view_map['importvcardsave']= 'importvcardsave';
$action_view_map['modulelistmenu']= 'modulelistmenu';
$action_view_map['ajaxui']= 'ajaxui';
$action_view_map['noaccess']= 'noaccess';

// SugarPDF
$action_view_map['sugarpdf']= 'sugarpdf';
$action_view_map['dc'] = 'dc';
$action_view_map['dcajax'] = 'dcajax';
$action_view_map['quick'] = 'quick';
$action_view_map['quickcreate'] = 'quickcreate';
$action_view_map['spot'] = 'spot';
$action_view_map['gs'] = 'gs';
$action_view_map['inlinefield'] = 'inlinefield';
$action_view_map['inlinefieldsave'] = 'inlinefieldsave';
$action_view_map['pluginlist'] = 'plugins';
$action_view_map['downloadplugin'] = 'downloadplugin';
$action_view_map['metadata'] = 'metadata';

$action_view_map['cubes'] = 'cubes';
$action_view_map['debug'] = 'debug';
?>
